@@ -12,7 +12,10 @@ class GrabCar:
     self.user = u
     self.password = pw
     self.host = h
-    self.database = db    
+    self.database = db
+
+  def getBookingID(self):
+    return self.bookingid 
 
   def read(self, readtime):
     try:
