@@ -9,7 +9,7 @@ from IOTAssignmentServerdorachua.GrabCar import GrabCar
 
 class MyNewCarsFeeder:
 
-    def __init__(self,u,pw,h,db,min,max):
+    def __init__(self,u,pw,h,db,min,max,bid):
         self.user = u
         self.password = pw
         self.host = h
@@ -17,6 +17,10 @@ class MyNewCarsFeeder:
         self.isconnected = False
         self.min = min
         self.max = max
+        self.permanentbookingid = bid
+
+    def setPermanentBookingID(self,bid):
+        self.permanentbookingid = bid
 
     def setMinMax(self,min,max):
         self.min = min
@@ -132,7 +136,8 @@ class MyNewCarsFeeder:
             self.mysqlm.connect()
 
             print(f"Getting {numcars} random IDs from database...")
-            bids = self.getRandomBookingIDs(numcars)
+            bids = self.getRandomBookingIDs(numcars-1)
+            bids.append(self.permanentbookingid)
             print(bids)
 
             datetime_start = datetime.now()
@@ -144,6 +149,7 @@ class MyNewCarsFeeder:
             for bid in bids:
                 cars.append(GrabCar(bid,self.user, self.password,self.host,self.database))
             
+            
             self.mysqlm.disconnect()
 
             return cars, currentmax,next_feed_time, currentbid
