@@ -2,7 +2,7 @@ import asyncio
 import sys
 from random import randint
 from random import random
-from datetime import datetime
+from datetime import datetime, timedelta 
 
 import json
 from IOTAssignmentUtilitiesdorachua import MySQLManager
@@ -19,6 +19,9 @@ class MySocketServer:
         self.database = db
         self.isconnected = False
         self.feeder = None
+        self.laststarttime = datetime.now()
+        self.lastSeconds=0
+        self.lastresetseconds=-1
 
     def setNewCarsFeeder(self,feeder):
         self.feeder = feeder
@@ -28,12 +31,18 @@ class MySocketServer:
         try:
 
             timenow = datetime.now()
+            nextfeedtime2 = self.laststarttime + timedelta(minutes = 5) 
 
-            if timenow == nextfeedtime and self.feeder is not None:
-                cars,timeout,nextfeedtime = self.feeder.getCars(5)            
+            if timenow == nextfeedtime2 and self.feeder is not None:
+                #self.lastresetSeconds = self.lastSeconds #161
+                self.laststarttime = timenow
+                newcars,timeout,nextfeedtime = self.feeder.getCars(5)
+                cars.append(newcars)
 
             data = await reader.read(100)        
             message = data.decode("utf-8")
+            requested_time = int(message)
+            self.lastSeconds = requested_time
             addr = writer.get_extra_info('peername')
 
             dt = datetime.now()
@@ -43,8 +52,12 @@ class MySocketServer:
             
             str_to_send = ""
             readings = []
+            
             for i in range(0,len(cars)):
-                reading = cars[i].read(message)
+                if requested_time<=self.lastresetseconds:
+                    reading = cars[i].read(requested_time)
+                else:
+                    reading = cars[i].read(requested_time-self.lastresetseconds)
                 if reading is not None:
                     readings.append(reading)
                 
